@@ -5,7 +5,10 @@ use utf8;
 
 package Neo4j::Driver::Type::Point;
 # ABSTRACT: Represents a Neo4j spatial point value
-$Neo4j::Driver::Type::Point::VERSION = '0.42';
+$Neo4j::Driver::Type::Point::VERSION = '0.43';
+
+# For documentation, see Neo4j::Driver::Types.
+
 
 use parent 'Neo4j::Types::Point';
 
@@ -55,39 +58,15 @@ Neo4j::Driver::Type::Point - Represents a Neo4j spatial point value
 
 =head1 VERSION
 
-version 0.42
-
-=head1 DESCRIPTION
-
-Represents a spatial point value in Neo4j.
-
-Spatial types are only supported in Neo4j version 3.4 and above.
-
-I<B<Note:> This module documentation will soon be replaced entirely
-by L<Neo4j::Driver::Types> and L<Neo4j::Types::Point>.>
-
-=head1 SEE ALSO
-
-=over
-
-=item * L<Neo4j::Driver::Types>
-
-=item * L<Neo4j::Types::Point>
-
-=item * Equivalent documentation for the official Neo4j drivers:
-L<Point (Java)|https://neo4j.com/docs/api/java-driver/5.2/org.neo4j.driver/org/neo4j/driver/types/Point.html>
-
-=item * L<"Spatial values" in Neo4j Cypher Manual|https://neo4j.com/docs/cypher-manual/5/syntax/spatial/>
-
-=back
+version 0.43
 
 =head1 AUTHOR
 
-Arne Johannessen (L<AJNN|https://arne.johannessen.de/>)
+Arne Johannessen (L<AJNN|https://metacpan.org/author/AJNN>)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016-2023 by Arne Johannessen.
+This software is Copyright (c) 2016-2024 by Arne Johannessen.
 
 This is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0 or (at your option) the same terms
